@@ -14,18 +14,10 @@ pub mod v1_global_turn_server;
 pub use self::v1_global_turn_server::V1GlobalTurnServer;
 pub mod v1_list_accelerator_response;
 pub use self::v1_list_accelerator_response::V1ListAcceleratorResponse;
-pub mod v1_list_projects_response;
-pub use self::v1_list_projects_response::V1ListProjectsResponse;
-pub mod v1_list_sessions_response;
-pub use self::v1_list_sessions_response::V1ListSessionsResponse;
 pub mod v1_list_sip_teleport_response;
 pub use self::v1_list_sip_teleport_response::V1ListSipTeleportResponse;
 pub mod v1_next_page;
 pub use self::v1_next_page::V1NextPage;
-pub mod v1_project;
-pub use self::v1_project::V1Project;
-pub mod v1_session;
-pub use self::v1_session::V1Session;
 pub mod v1_sip_teleport_response;
 pub use self::v1_sip_teleport_response::V1SipTeleportResponse;
 pub mod v1_sip_teleport_status;
